SystemOrganization addCategory: #ConfigurationOfTeachable!

Object subclass: #ConfigurationOfTeachable
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfTeachable'!

!ConfigurationOfTeachable class methodsFor: 'private' stamp: 'tbn 1/13/2010 13:11'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfTeachable class methodsFor: 'private' stamp: 'tbn 1/13/2010 13:11'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfTeachable class methodsFor: 'metacello tool support' stamp: 'tbn 1/13/2010 13:10'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfTeachable class methodsFor: 'metacello tool support' stamp: 'tbn 1/13/2010 13:10'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfTeachable class methodsFor: 'loading' stamp: 'tbn 2/19/2010 23:18'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfTeachable class methodsFor: 'metacello tool support' stamp: 'tbn 1/13/2010 13:11'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfTeachable class methodsFor: 'accessing' stamp: 'tbn 1/13/2010 13:10'!
project

	^self new project! !

!ConfigurationOfTeachable methodsFor: 'baselines' stamp: 'tbn 2/27/2013 15:03'!
baseline10: spec
    <version: '1.0-baseline'>
    
    spec for: #common do: [
        spec 
			blessing: #baseline;
			description: '1.0 baseline for Teachable';
			repository: 'http://smalltalkhub.com/mc/TorstenBergmann/Teachable/main'.     
			 
        spec package: 'Teachable-Core'.
		 spec package: 'Teachable-Tests' with: [ spec requires: #('Teachable-Core' ) ].		
				
		 spec
			group: 'all' with: #('Tests');		
			group: 'default' with: #('Teachable-Core' );
			group: 'Tests' with: #('Teachable-Tests' ).
								   
    ]
      
        
! !

!ConfigurationOfTeachable methodsFor: 'accessing' stamp: 'tbn 1/13/2010 13:05'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfTeachable methodsFor: 'symbolic versions' stamp: 'tbn 4/16/2012 14:17'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.0'.! !

!ConfigurationOfTeachable methodsFor: 'versions' stamp: 'tbn 4/16/2012 14:21'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #'release'.	 
		spec description: 'first release'. 
		spec author: 'Torsten Bergmann'.
		spec timestamp: '3/1/2010 16:49'.
		spec package: 'Teachable-Core' with: 'Teachable-Core-tbn.1'.
		spec package: 'Teachable-Tests' with: 'Teachable-Tests-tbn.1'.		
	]! !
